/* 

                          Firewall Builder

                 Copyright (C) 2001 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: SimpleProgressDialog.cc,v 1.3 2003/03/04 05:40:05 vkurland Exp $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "config.h"
#include "SimpleProgressDialog.hh"

#include <gtk--.h>

SimpleProgressDialog::SimpleProgressDialog() {}

void SimpleProgressDialog::setTitle(const string &t)
{
    set_title(t);
}

void SimpleProgressDialog::setText(const string &t)
{
    text->set_text(t);
}

void SimpleProgressDialog::setProgressBarRange(gfloat min,gfloat max)
{
    progressbar->configure(0.0,min,max);
}

void SimpleProgressDialog::setProgressBarValue(gfloat val)
{
    progressbar->set_value(val);

    while ( gtk_events_pending() )
	gtk_main_iteration();
}
